@@ -1,8 +1,8 @@
 use std::{ops::Deref, rc::Rc};
 
-#[derive(Debug)]
+/// Context which holds a reference to the service `T`.
 pub struct ServiceContext<T> {
-    service: Rc<T>,
+    pub service: Rc<T>,
 }
 
 impl<T> ServiceContext<T> {
